==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/button/template/highlyStructured/HighlyStructuredLocalizableParameterBuilder.java <==
package it.auties.whatsapp.model.button.template.highlyStructured;

public class HighlyStructuredLocalizableParameterBuilder {
    private java.lang.String defaultValue;
    private java.util.Optional<it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredCurrency> parameterCurrency;
    private java.util.Optional<it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredDateTime> parameterDateTime;

    public HighlyStructuredLocalizableParameterBuilder() {
        defaultValue = null;
        parameterCurrency = java.util.Optional.empty();
        parameterDateTime = java.util.Optional.empty();
    }

    public HighlyStructuredLocalizableParameterBuilder defaultValue(java.lang.String defaultValue) {
        this.defaultValue = defaultValue;
        return this;
    }
    public HighlyStructuredLocalizableParameterBuilder parameterCurrency(java.util.Optional<it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredCurrency> parameterCurrency) {
        this.parameterCurrency = parameterCurrency;
        return this;
    }
    public HighlyStructuredLocalizableParameterBuilder parameterCurrency(it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredCurrency parameterCurrency) {
        this.parameterCurrency = java.util.Optional.ofNullable(parameterCurrency);
        return this;
    }
    public HighlyStructuredLocalizableParameterBuilder parameterDateTime(java.util.Optional<it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredDateTime> parameterDateTime) {
        this.parameterDateTime = parameterDateTime;
        return this;
    }
    public HighlyStructuredLocalizableParameterBuilder parameterDateTime(it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredDateTime parameterDateTime) {
        this.parameterDateTime = java.util.Optional.ofNullable(parameterDateTime);
        return this;
    }

    public it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredLocalizableParameter build() {
        return new it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredLocalizableParameter(defaultValue, parameterCurrency, parameterDateTime);
    }
}

==> cobalt-0.0.7-sources.jar: it/auties/whatsapp/model/button/template/highlyStructured/HighlyStructuredLocalizableParameterBuilder.java <==
package it.auties.whatsapp.model.button.template.highlyStructured;

public class HighlyStructuredLocalizableParameterBuilder {
    private java.lang.String defaultValue;
    private java.util.Optional<it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredCurrency> parameterCurrency;
    private java.util.Optional<it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredDateTime> parameterDateTime;

    public HighlyStructuredLocalizableParameterBuilder() {
        defaultValue = null;
        parameterCurrency = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        parameterDateTime = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
    }

    public HighlyStructuredLocalizableParameterBuilder defaultValue(java.lang.String defaultValue) {
        this.defaultValue = defaultValue;
        return this;
    }

    public HighlyStructuredLocalizableParameterBuilder parameterCurrency(it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredCurrency parameterCurrency) {
        this.parameterCurrency = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(parameterCurrency);
        return this;
    }

    public HighlyStructuredLocalizableParameterBuilder parameterDateTime(it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredDateTime parameterDateTime) {
        this.parameterDateTime = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(parameterDateTime);
        return this;
    }

    public it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredLocalizableParameter build() {
        return new it.auties.whatsapp.model.button.template.highlyStructured.HighlyStructuredLocalizableParameter(defaultValue, parameterCurrency, parameterDateTime);
    }

}
